#!/bin/bash
# http://www.gnu.org/software/grub/grub-2.en.html
# http://www.linuxfromscratch.org/lfs/view/development/chapter08/grub.html
SRC_URL=ftp://alpha.gnu.org/gnu/grub
#
# optionally used by grub-mkfont
# The fonts in this package are now in public domain.
FONT_URL=http://unifoundry.com
#
# alternate source
# http://unifoundry.com/unifont-5.1.20080820.bdf.gz
#
# script : til <rob DOT til DOT freedman AT googlemail DOT com>
set -e -u -x

#grub
version=1.98
build=64.1
arch=i486
tune=i686

pkgname=grub-$version
package=$pkgname-$arch-$build

# get grub source if needed
[ -e $pkgname.tar.gz ] || wget -q $SRC_URL/$pkgname.tar.gz

# Andreas Born's sg2conf - or or leave empty without
SG2_PKG=sg2conf-1.1.13 #SG2_PKG= 
SG2_URL=http://gaia.homelinux.org/zenwalk/sg2conf
[ -z $SG2_PKG ] || [ -e $SG2_PKG.tar.bz2 ] || wget -q $SG2_URL/$SG2_PKG.tar.bz2

# unifont.bdf used by grub-mkfont; peeled off from debian
if [ ! -e unifont-5.1.20080820.pcf ]; then
	wget -qcN $FONT_URL/unifont-5.1.20080820.pcf.gz
	gunzip unifont-5.1.20080820.pcf.gz
fi
#	ar x ./$UTF_BDF  ./data.tar.gz &&
#	tar xf ./data.tar.gz --strip-components=3 ./usr/src/unifont.bdf
#	rm ./data.tar.gz
 
## build locations
CWD=$(pwd)
TMP=${TMP:-$CWD}

PKG=$TMP/$package
SRC=$TMP/$pkgname

[ -d $PKG ] && rm -fr $PKG
[ -d $SRC ] && rm -fr $SRC

mkdir -p $PKG/{install,etc/default,boot/grub,usr/{src,doc}/$pkgname}

## build starts
tar xf $CWD/$pkgname.tar.gz -C $TMP
cd $SRC
#./configure --help >$CWD/configure-help
#
#FONT_SOURCE=$CWD/unifont.bdf 
CFLAGS="-Os -march=$arch -mtune=$tune" \
CXXFLAGS="-Os -march=$arch -mtune=$tune" \
FONT_SOURCE=$CWD/unifont-5.1.20080820.pcf \
  ./configure \
    --prefix=/usr \
    --exec-prefix=/\
    --sbindir=/sbin \
    --sysconfdir=/etc \
	--mandir=/usr/man \
    --infodir=/usr/info \
    --enable-grub-mkfont \
    --disable-efiemu
	
make || exit 1
make install DESTDIR=$PKG
# helperline
(cd $PKG; find . -printf "%y %M %u:%g %p %l\n" ) >$CWD/make.installed

# docs
gzip -9 ChangeLog
cp -a AUTHORS COPYING ChangeLog.gz NEWS README THANKS TODO \
	$PKG/usr/doc/$pkgname

# Andreas Born's sg2conf
[ -z $SG2_PKG ] || (
	tar xf $CWD/$SG2_PKG.tar.bz2 -C $TMP
	cd $TMP/$SG2_PKG
	sed -i 's_/usr/lib/grub_/lib/grub_g' 05_zenwalk_theme
	sed -i 's_/share/images_/share/grub_g' 05_zenwalk_theme
	DESTDIR=$PKG PREFIX=/usr ETCDIR=/etc ZWTHEME=true GRUB2CONFIG=true sh ./install.sh 
	# docs
	cp -a README $PKG/usr/doc/$pkgname/README.sgconf
	cp -a CHANGELOG $PKG/usr/doc/$pkgname/CHANGELOG.sgconf
)
# more complete ascii latin1 font
#./grub-mkfont -o $PKG/boot/grub/latin1.pf2 usr/share/fonts/misc/unifont.pcf.gz  --range=0x0000-0x0241,0x2190-0x21FF,0x2500-0x259f 

cd $PKG
# even with /usr blown up
mv usr/share/grub/unicode.pf2 boot/grub/

# strip symbols
find . |xargs file |grep "executable" |grep ELF |cut -f 1 -d : |xargs -r strip --strip-unneeded 

# zip man/info pages
find usr/{info,man} -type f -name "*.?" -o -iname '*.info' | xargs gzip -9

# doinst.sh
cat <<"EOF" > install/doinst.sh
#
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

config etc/default/grub.new
EOF

# merge dir with /usr/info/dir
[ -e usr/info/dir ] && { \
  cat << "EOF" >> install/doinst.sh
# Update the /usr/info/dir info-database with grub.info
if [ -x usr/bin/install-info ] ; then
  usr/bin/install-info --info-dir=usr/info usr/info/grub.info.gz 2>/dev/null
fi
EOF
# done with it
  rm usr/info/dir 
}
# put a slack-desc in place
#         |-----handy-ruler------------------------------------------------------|
cat <<EOF > install/slack-desc
grub: grub (GNU GRUB is a Multiboot boot loader)
grub: 
grub: GRUB is GRand Unified Bootloader, which was originally designed
grub: and implemented by Erich Stefan Boleyn.
grub:
grub: 
grub: $SG2_URL
EOF
#
cat <<"EOF" > etc/default/grub.new
# If you change this file, run 'update-grub' afterwards to update
# /boot/grub/grub.cfg.

GRUB_DISTRIBUTOR="`cat /etc/zenwalk-version 2> /dev/null`"

GRUB_DEFAULT=0
GRUB_TIMEOUT=5

GRUB_CMDLINE_LINUX=""
GRUB_CMDLINE_LINUX_DEFAULT="splash=silent"
GRUB_USE_LINUX_SYMLINK="yes"

# The resolution used on graphical terminal
# note that you can use only modes which your graphic card supports via VBE
# you can see them in real GRUB with the command `vbeinfo'
#GRUB_GFXMODE=640x480
#GRUB_TERMINAL_OUTPUT="gfxterm"

# Uncomment to disable graphical terminal 
#GRUB_TERMINAL=console

# Uncomment if you don't want GRUB to pass "root=UUID=xxx" parameter to Linux
#GRUB_DISABLE_LINUX_UUID=true

# Uncomment to disable generation of recovery mode menu entrys
#GRUB_DISABLE_LINUX_RECOVERY="true"
#
GRUB_FONT="/boot/grub/unicode.pf2"

EOF
# copy build script
cp $CWD/build-grub.sh usr/src/$pkgname

fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz
#
cd $CWD
md5sum $package.txz >$package.md5
depfinder $PKG >$package.dep

